class Article < ActiveRecord::Base
  attr_accessible :content, :title, :user_id, :summary, :category_id, :tag_list
  belongs_to :user
  belongs_to :category, counter_cache: true

  has_and_belongs_to_many :tags

  validates_presence_of :title, :content, :user, :summary, :category
  validates_length_of :summary, within: 20..180

  def tag_list=(new_tag_list)
    self.transaction do
      # to get asap how this works just draw the Venn diagramm
      new_tag_list = new_tag_list.split(",").map {|t| t.downcase.strip}
      old_tag_list = self.tags.map(&:name)

      # add tags the article has not been tagged with before
      to_add = new_tag_list - old_tag_list
      to_add.each do |tag|
        tags << Tag.find_or_create_by_name(tag)
      end

      # delete tags which are no longer included in the list
      to_remove = old_tag_list - new_tag_list
      to_remove.each do |tag|
        tags.delete Tag.find_by_name(tag)
      end

      # for the intersection of the sets there is nothing to do, because these
      # taggins have not been changed
    end
  end

  def tag_list
    tags.map(&:name).join(", ")
  end
end
